{$APPTYPE CONSOLE}

program city_model;
const
  MAX_N = 100000;
type
  array_n = array[1..MAX_N] of integer;
var
  x, y, u, v, h: array_n;
  x1, y1, u1, v1, h1: array_n;
  s: integer;
  n: integer;
  i: integer;

  function min(a, b: integer): integer;
  begin
    if (a < b) then
      Result := a
    else
      Result := b;
  end;

  function max(a, b: integer): integer;
  begin
    if (a > b) then
      Result := a
    else
      Result := b;
  end;

  function intervals_intersection_length(a, b: integer; c, d: integer): integer;
  var
    l, r: integer;
  begin
    l := max(a, c);
    r := min(b, d);
    if (l > r) then
      Result := 0
    else
      Result := r-l;
  end;

  procedure read_with_checking(var x: integer);
  begin
    if SeekEof(input) then
      halt(101);
    read(x);
  end;

  procedure swap_int(var a, b: integer);
  var
    tmp: integer;
  begin
    tmp := a;
    a := b;
    b := tmp;
  end;

  procedure quick_sort(var x, y, u, v, h: array_n; l, r: integer);
  //      x[i],
  //   x[i] --   y[i].
  var
    q: integer;

    function partition(l, r: integer): integer;
    var
      xx, yy: integer;
      i, j: integer;
    begin
      xx := x[l]; yy := y[l];
      i := l-1; j := r+1;
      while true do
      begin
        repeat
          dec(j);
        until (x[j] < xx) or (x[j] = xx) and (y[j] <= yy);
        repeat
          inc(i);
        until (x[i] > xx) or (x[i] = xx) and (y[i] >= yy);
        if (i < j) then
        begin
          swap_int(x[i], x[j]);
          swap_int(y[i], y[j]);
          swap_int(u[i], u[j]);
          swap_int(v[i], v[j]);
          swap_int(h[i], h[j]);
        end
        else
        begin
          Result := j;
          break;
        end;
      end;
    end;

  begin
    if (l < r) then
    begin
      q := partition(l, r);
      quick_sort(x, y, u, v, h, l, q);
      quick_sort(x, y, u, v, h, q+1, r);
    end;
  end;

  procedure assert_rectangles_do_not_intersect;
  var
    i, j: integer;
  begin
    for i := 1 to n do
    begin
      for j := i+1 to n do
      begin
        if not ((intervals_intersection_length(x[i], u[i], x[j], u[j]) = 0) or
          (intervals_intersection_length(y[i], v[i], y[j], v[j]) = 0)) then
            halt(102);
      end;
    end;
  end;

  procedure remove_contacts(var x, y, u, v, h: array_n;
    var x1, y1, u1, v1, h1: array_n);
  var
    i, j: integer;
  begin
    quick_sort(u, v, x, y, h, 1, n);
    quick_sort(x1, y1, u1, v1, h1, 1, n);
    i := 1;
    j := 1;
    while (i <= n) and (j <= n) do
    begin
      if (u[i] < x1[j]) then
        i := i+1
      else if (u[i] > x1[j]) then
        j := j+1
      else //u[i] = x1[j]
      begin
        while (i <= n) and (j <= n) and (u[i] = x1[j]) do
        begin
          if (v[i] < y1[j]) then
            i := i+1
          else if (v1[j] < y[i]) then
            j := j+1
          else
          begin
            s := s - 2*intervals_intersection_length(
              y[i], v[i], y1[j], v1[j])*min(h[i], h1[j]);
            if (v[i] < v1[j]) then
              i := i+1
            else
              j := j+1;
          end;
        end;        
      end;
    end;
  end;

  procedure copy_seq;
  var
    i: integer;
  begin
    for i := 1 to n do
    begin
      x1[i] := x[i];
      y1[i] := y[i];
      u1[i] := u[i];
      v1[i] := v[i];
      h1[i] := h[i];
    end;
  end;

begin
  assign(input, 'input.txt');
  reset(input);
  assign(output, 'output.txt');
  rewrite(output);

  if SeekEof(input) then halt(103);
  read(n);
  if not ((1 <= n) and (n <= 100000)) then halt(104);
  for i := 1 to n do
  begin
    read_with_checking(x[i]);
    read_with_checking(y[i]);
    read_with_checking(u[i]);
    read_with_checking(v[i]);
    read_with_checking(h[i]);
    if not ((0 <= x[i]) and (x[i] < u[i]) and (u[i] <= 10000)) then halt(105);
    if not ((0 <= y[i]) and (y[i] < v[i]) and (v[i] <= 10000)) then halt(106);
    if not ((0 < h[i]) and (h[i] <= 100)) then halt(107);
  end;
  if not (SeekEof(input)) then halt(108);

  if (n <= 2000) then
    assert_rectangles_do_not_intersect;

  s := 0;
  for i := 1 to n do
  begin
    s := s + 2*((u[i]-x[i])+(v[i]-y[i]))*h[i] + (u[i]-x[i])*(v[i]-y[i]);
    if not (s <= 1000000000) then halt(109);
  end;

  copy_seq;
  remove_contacts(x, y, u, v, h, x1, y1, u1, v1, h1);
  remove_contacts(y, x, v, u, h, y1, x1, v1, u1, h1);

  write(s);

  close(input);
  close(output);
end.